darkhistory.electrons.ics.ics\_engloss\_spectrum.engloss\_spec\_diff
====================================================================

.. currentmodule:: darkhistory.electrons.ics.ics_engloss_spectrum

.. autofunction:: engloss_spec_diff